@@ -11,13 +11,13 @@ use warnings;
 use Carp;
 use English qw/ -no_match_vars /;
 
-our $VERSION     = 0.002;
+our $VERSION     = 0.03;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
 
 sub perl {
-    my ($self) = @_;
+    my ($self, $options) = @_;
     my $path = $ENV{PERLBREW_PERL};
     return if !$path;
 
@@ -36,7 +36,7 @@ App::PS1::Plugin::Perl - Shows current version of Perl if using perlbrew
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Perl version 0.002.
+This documentation refers to App::PS1::Plugin::Perl version 0.03.
 
 =head1 SYNOPSIS
 
