@@ -10,10 +10,10 @@ use strict;
 use warnings;
 use English qw/ -no_match_vars /;
 
-our $VERSION = 0.002;
+our $VERSION = 0.03;
 
 sub ruby {
-    my ($self) = @_;
+    my ($self, $options) = @_;
     my $name = $ENV{RUBY_VERSION};
     return if !$name;
 
@@ -34,7 +34,7 @@ App::PS1::Plugin::Ruby - Shows current version of ruby if using rvm
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Ruby version 0.002.
+This documentation refers to App::PS1::Plugin::Ruby version 0.03.
 
 =head1 SYNOPSIS
 
